import { log } from "console";
import { randomBytes } from "crypto";

/**
 * Template string type for AUIDs
 */
export type AUID = `${string}-${string}-${string}-${string}`;

/**
 * Generates a crytografically strong AUID
 * 
 * With `(2 ^ 4) ^ (16*4)` or `2 ^ 256` or `1.1579209e+77` possible combinations
 */
export function generateAUID(): AUID {
    const bytes = randomBytes(32).toString('hex'); // 64 hex characters
    return `${bytes.slice(0, 16)}-${bytes.slice(16, 32)}-${bytes.slice(32, 48)}-${bytes.slice(48, 64)}` as AUID;
};

/**
 * Generates a crytografically strong AUID **inside of the browser environment**
 * 
 * With `(2 ^ 4) ^ (16*4)` or `2 ^ 256` or `1.1579209e+77` possible combinations
 */
export function generateAUID_dom(): AUID {
	const bytes = new Uint8Array(32);
	crypto.getRandomValues(bytes);

	// Convert the bytes to a hexadecimal string
	const hexArray = Array.from(bytes).map(byte => byte.toString(16).padStart(2, "0")).join("");

	return `${hexArray.slice(0, 16)}-${hexArray.slice(16, 32)}-${hexArray.slice(32, 48)}-${hexArray.slice(48, 64)}` as AUID;
};


/**
 * Fullproof regex for AUIDs
 */
export const isAUID = new RegExp(/^[a-f0-9]{16}-[a-f0-9]{16}-[a-f0-9]{16}-[a-f0-9]{16}$/);
